@@ -28,12 +28,12 @@ namespace KDevPG
 {
 void GenerateAst::operator()()
 {
-  out << globalSystem.namespaceCode << endl;
+  out << globalSystem.namespaceCode << Qt::endl;
 
   out << "struct " << globalSystem.exportMacro << " AstNode";
 
-  out << "{" << endl
-      << "enum AstNodeKind {" << endl;
+  out << "{" << Qt::endl
+      << "enum AstNodeKind {" << Qt::endl;
 
   int node_id = 1000;
   for (QMap<QString, Model::SymbolItem*>::iterator it = globalSystem.symbols.begin();
@@ -42,27 +42,27 @@ void GenerateAst::operator()()
       Model::SymbolItem *sym = (*it);
       if(isOperatorSymbol(sym))
       {
-        out << "Prefix" << sym->mCapitalizedName << "Kind" << " = " << node_id << "," << endl;
+        out << "Prefix" << sym->mCapitalizedName << "Kind" << " = " << node_id << "," << Qt::endl;
         ++node_id;
-        out << "Postfix" << sym->mCapitalizedName << "Kind" << " = " << node_id << "," << endl;
+        out << "Postfix" << sym->mCapitalizedName << "Kind" << " = " << node_id << "," << Qt::endl;
         ++node_id;
-        out << "Binary" << sym->mCapitalizedName << "Kind" << " = " << node_id << "," << endl;
+        out << "Binary" << sym->mCapitalizedName << "Kind" << " = " << node_id << "," << Qt::endl;
         ++node_id;
-        out << "Ternary" << sym->mCapitalizedName << "Kind" << " = " << node_id << "," << endl;
+        out << "Ternary" << sym->mCapitalizedName << "Kind" << " = " << node_id << "," << Qt::endl;
         ++node_id;
       }
-      out << sym->mCapitalizedName << "Kind" << " = " << node_id << "," << endl;
+      out << sym->mCapitalizedName << "Kind" << " = " << node_id << "," << Qt::endl;
       ++node_id;
     }
 
-  out << "AST_NODE_KIND_COUNT" << endl
-      << "};" << endl << endl
-      << "int kind;" << endl
-      << "qint64 startToken;" << endl
-      << "qint64 endToken;" << endl
-      << globalSystem.astCode << endl
-      << "};" << endl
-      << endl;
+  out << "AST_NODE_KIND_COUNT" << Qt::endl
+      << "};" << Qt::endl << Qt::endl
+      << "int kind;" << Qt::endl
+      << "qint64 startToken;" << Qt::endl
+      << "qint64 endToken;" << Qt::endl
+      << globalSystem.astCode << Qt::endl
+      << "};" << Qt::endl
+      << Qt::endl;
 
   GenerateAstRule gen(out);
   for( World::SymbolSet::const_iterator it = globalSystem.symbols.constBegin(); it != globalSystem.symbols.constEnd(); ++it )
@@ -91,7 +91,7 @@ void GenerateAst::operator()()
     gen(*i);
     i = next;
   }
-  out << endl;
+  out << Qt::endl;
 }
 
 void GenerateAstRule::operator()(Model::SymbolItem *sym)
@@ -132,72 +132,72 @@ void GenerateAstRule::visitEvolve(Model::EvolveItem *node)
   {
     out << "struct " << globalSystem.exportMacro << " " << sym->mCapitalizedName << "Ast: public "
         << globalSystem.astBaseClasses.value(sym->mName, "AstNode")
-        << "{ enum { KIND = " << sym->mCapitalizedName << "Kind }; };" << endl << endl;
+        << "{ enum { KIND = " << sym->mCapitalizedName << "Kind }; };" << Qt::endl << Qt::endl;
     #define O(thestr) \
     out << "struct " << globalSystem.exportMacro << thestr << sym->mCapitalizedName << "Ast: public " \
         << sym->mCapitalizedName << "Ast" \
-        << " {" << endl \
-        << "enum { KIND =" << thestr << sym->mCapitalizedName << "Kind };" << endl \
-        << "AstNode *first;" << endl \
+        << " {" << Qt::endl \
+        << "enum { KIND =" << thestr << sym->mCapitalizedName << "Kind };" << Qt::endl \
+        << "AstNode *first;" << Qt::endl \
         << thestr << sym->mCapitalizedName << "Ast(" \
-        << ")" << endl \
-        << "{\n}" << endl \
+        << ")" << Qt::endl \
+        << "{\n}" << Qt::endl \
         << thestr << sym->mCapitalizedName << "Ast(" \
-        << "AstNode *first)" << endl \
-        << ": first(first)" << endl \
-        << "{\n}" << endl;\
+        << "AstNode *first)" << Qt::endl \
+        << ": first(first)" << Qt::endl \
+        << "{\n}" << Qt::endl;\
         mGenerated.insert(thestr);
         
     O(" Prefix")
 
     DefaultVisitor::visitEvolve(node);
       
-    out << "};" << endl << endl;
+    out << "};" << Qt::endl << Qt::endl;
     O(" Postfix")
 
     DefaultVisitor::visitEvolve(node);
       
-    out << "};" << endl << endl;
+    out << "};" << Qt::endl << Qt::endl;
     
     #undef O
     
     out << "struct " << globalSystem.exportMacro << " Binary" << sym->mCapitalizedName << "Ast: public "
         << sym->mCapitalizedName << "Ast"
-        << " {" << endl
-        << "enum { KIND = Binary" << sym->mCapitalizedName << "Kind };" << endl
-        << "AstNode *first;" << endl
-        << "AstNode *second;" << endl
+        << " {" << Qt::endl
+        << "enum { KIND = Binary" << sym->mCapitalizedName << "Kind };" << Qt::endl
+        << "AstNode *first;" << Qt::endl
+        << "AstNode *second;" << Qt::endl
         << "Binary" << sym->mCapitalizedName << "Ast("
-        << "AstNode *first)" << endl
-        << ": first(first)" << endl
-        << "{\n}" << endl;
+        << "AstNode *first)" << Qt::endl
+        << ": first(first)" << Qt::endl
+        << "{\n}" << Qt::endl;
     DefaultVisitor::visitEvolve(node);
-    out << "};" << endl << endl;
+    out << "};" << Qt::endl << Qt::endl;
     
     out << "struct " << globalSystem.exportMacro << " Ternary" << sym->mCapitalizedName << "Ast: public "
         << sym->mCapitalizedName << "Ast"
-        << " {" << endl
-        << "enum { KIND = Ternary" << sym->mCapitalizedName << "Kind };" << endl
-        << "AstNode *first;" << endl
-        << "AstNode *second;" << endl
-        << "AstNode *third;" << endl
+        << " {" << Qt::endl
+        << "enum { KIND = Ternary" << sym->mCapitalizedName << "Kind };" << Qt::endl
+        << "AstNode *first;" << Qt::endl
+        << "AstNode *second;" << Qt::endl
+        << "AstNode *third;" << Qt::endl
         << "Ternary" << sym->mCapitalizedName << "Ast("
-        << "AstNode *first)" << endl
-        << ": first(first)" << endl
-        << "{\n}" << endl;
+        << "AstNode *first)" << Qt::endl
+        << ": first(first)" << Qt::endl
+        << "{\n}" << Qt::endl;
     DefaultVisitor::visitEvolve(node);
-    out << "};" << endl << endl;
+    out << "};" << Qt::endl << Qt::endl;
   }
   else
   {
     out << "struct " << globalSystem.exportMacro << " " << sym->mCapitalizedName << "Ast: public "
         << globalSystem.astBaseClasses.value(sym->mName, "AstNode")
-        << " {" << endl
-        << "enum { KIND = " << sym->mCapitalizedName << "Kind };" << endl << endl;
+        << " {" << Qt::endl
+        << "enum { KIND = " << sym->mCapitalizedName << "Kind };" << Qt::endl << Qt::endl;
 
     DefaultVisitor::visitEvolve(node);
 
-    out << "};" << endl << endl;
+    out << "};" << Qt::endl << Qt::endl;
   }
 }
 
@@ -209,7 +209,7 @@ void GenerateAstRule::visitVariableDeclaration(Model::VariableDeclarationItem *n
     {
       gen_var_decl(node);
 
-      out << ";" << endl;
+      out << ";" << Qt::endl;
 
       mNames.insert(node->mName);
     }
@@ -229,11 +229,11 @@ void GenerateAstRule::visitAlternative(Model::AlternativeItem *node)
 #if defined(AST_OPT_BRANCH)
   if (!in_alternative)
     {
-      out << "union" << endl
-          << "{" << endl
-          << "AstNode *__nodeCast;" << endl
-          << "qint64 __token_cast;" << endl
-          << endl;
+      out << "union" << Qt::endl
+          << "{" << Qt::endl
+          << "AstNode *__nodeCast;" << Qt::endl
+          << "qint64 __token_cast;" << Qt::endl
+          << Qt::endl;
     }
 #endif
 
@@ -241,7 +241,7 @@ void GenerateAstRule::visitAlternative(Model::AlternativeItem *node)
 
 #if defined(AST_OPT_BRANCH)
   if (!in_alternative)
-    out << "}; // union" << endl;
+    out << "}; // union" << Qt::endl;
 #endif
 
   switchAlternative(in_alternative);
@@ -254,8 +254,8 @@ void GenerateAstRule::visitCons(Model::ConsItem *node)
 #if defined(AST_OPT_BRANCH)
   if (!in_cons)
     {
-      out << "struct" << endl
-          << "{" << endl;
+      out << "struct" << Qt::endl
+          << "{" << Qt::endl;
     }
 #endif
 
@@ -264,7 +264,7 @@ void GenerateAstRule::visitCons(Model::ConsItem *node)
 #if defined(AST_OPT_BRANCH)
   if (!in_cons)
     {
-      out << "}; // struct" << endl;
+      out << "}; // struct" << Qt::endl;
       mNames.clear();
     }
 #endif
@@ -294,7 +294,7 @@ void GenerateAstFwd::operator()()
        it != globalSystem.symbols.end(); ++it)
   {
     Model::SymbolItem *sym = *it;
-    #define O(name) out << "struct " << name << "Ast;" << endl;
+    #define O(name) out << "struct " << name << "Ast;" << Qt::endl;
     O(sym->mCapitalizedName)
     if(isOperatorSymbol(sym))
     {
