@@ -64,7 +64,7 @@ inline void printChar(QTextStream& o, uint x)
   else if(x >= 32 && x <= 126)
     o << '\'' << (char)x << '\'';
   else
-    o << hex << "\\" << qSetFieldWidth(2) << qSetPadChar('0') << x;
+    o << Qt::hex << "\\" << qSetFieldWidth(2) << qSetPadChar('0') << x;
   o.setPadChar(pad);
   o.setFieldWidth(width);
   o.setIntegerBase(base);
