@@ -35,6 +35,7 @@ using namespace std;
 // TODO: Line-End etc.
 // TODO: Deactivate/activate rules (have to keep the bitsets of possible final states)
 
+
 #define q_Hash_to_tr1_hash(type) \
 namespace std                                               \
 {                                                           \
@@ -47,11 +48,6 @@ namespace std                                               \
     };                                                      \
 }
 
-#if (QT_VERSION < QT_VERSION_CHECK(5, 14, 0))
-// Qt >= 5.14 already has std::hash for QBitArray
-q_Hash_to_tr1_hash(QBitArray)
-#endif
-
 namespace KDevPG
 {
 
@@ -70,10 +66,10 @@ inline QString codeForDot(QString str)
     int npos = str.indexOf("\n\01!ASIgnore\"!!\n# ", pos);
     if(npos == -1)
     {
-      out += str.midRef(pos);
+      out += QStringView(str).mid(pos);
       break;
     }
-    out += str.midRef(pos, npos - pos);
+    out += QStringView(str).mid(pos, npos - pos);
     int nlpos = str.indexOf('\n', npos + 17);
     int codeendpos = str.indexOf("\n\01!AS/Ignore\"!!\n", nlpos);
     if(nlpos == -1 || codeendpos == -1)
@@ -81,7 +77,7 @@ inline QString codeForDot(QString str)
       out += "<junk>";
       break;
     }
-    out += str.midRef(nlpos + 1, codeendpos - nlpos - 1);
+    out += QStringView(str).mid(nlpos + 1, codeendpos - nlpos - 1);
     pos = codeendpos + 17;
   }
   return out.replace('\"', "\\\"").replace('\n', '\t').trimmed();
@@ -135,7 +131,7 @@ public:
     /// .dot-output
     void dotOutput(QTextStream& out, const QString& name)
     {
-      out << "digraph " << name << "{" << endl;
+      out << "digraph " << name << "{" << Qt::endl;
       for(size_t i = 0; i != nstates; ++i)
       {
         out << "s" << i << " [ label = \"" << i << "\"";
@@ -145,24 +141,24 @@ public:
           out << ", shape=oval";
         if(accept[i] != 0)
           out << ", penwidth=4";
-        out << " ];" << endl;
+        out << " ];" << Qt::endl;
       }
       for(size_t i = 1; i <= numActions; ++i)
       {
-        out << "f" << i << " [ label = \"" << codeForDot(actions[i]) << "\", shape=rect, penwidth=2 ];" << endl;
+        out << "f" << i << " [ label = \"" << codeForDot(actions[i]) << "\", shape=rect, penwidth=2 ];" << Qt::endl;
       }
       for(size_t i = 0; i != nstates; ++i)
       {
         for(auto j = rules[i].begin(); j != rules[i].end(); ++j)
         {
-          out << "s" << i << " -> " << "s" << j->second << " [ label = \"" << j->first << "\" ];" << endl;
+          out << "s" << i << " -> " << "s" << j->second << " [ label = \"" << j->first << "\" ];" << Qt::endl;
         }
         if(accept[i] != 0)
         {
-          out << "s" << i << " -> " << "f" << accept[i] << ";" << endl;
+          out << "s" << i << " -> " << "f" << accept[i] << ";" << Qt::endl;
         }
       }
-      out << "}" << endl;
+      out << "}" << Qt::endl;
     }
     /// Debugging output
     void inspect()
@@ -186,7 +182,7 @@ public:
         size_t state = 0;
         foreach(const QChar c, str)
         {
-            foreach(const auto& r, rules[state])
+            for(const auto& r : rules[state])
             {
                 if(r.first.accepts(c.unicode())) // make it more portable!!
                 {
@@ -213,7 +209,7 @@ public:
           action = accept[state];
         }
         quint64 chr = iter.next(); // make it more portable!!
-        foreach(const auto& r, rules[state])
+        for(const auto& r : rules[state])
         {
           if(r.first.accepts(chr))
           {
@@ -272,7 +268,7 @@ public:
         {
             size_t curr = todo.top();
             todo.pop();
-            foreach(const auto& i, rules[curr])
+            for(const auto& i : rules[curr])
             {
                 if(!arrivable[i.second])
                 {
@@ -316,9 +312,9 @@ public:
     bool sameGroup(size_t ngroups, const vector<size_t>& ogroups, size_t x, size_t y)
     {
         vector<CharSet> xsets(ngroups), ysets(ngroups);
-        foreach(const auto& i, rules[x])
+        for(const auto& i : rules[x])
             xsets[ogroups[i.second]].unite(i.first);
-        foreach(const auto& i, rules[y])
+        for(const auto& i : rules[y])
             ysets[ogroups[i.second]].unite(i.first);
         return xsets == ysets;
     }
@@ -359,7 +355,7 @@ public:
         for(size_t i = 0; i != nstates; ++i)
         {
             _accept[groups[i]] = accept[i];
-            foreach(const auto& j, rules[i])
+            for(const auto& j : rules[i])
                 _rules[groups[i]].push_back(make_pair(j.first, groups[j.second]));
         }
         rules = _rules;
@@ -368,7 +364,7 @@ public:
         for(size_t i = 0; i != nstates; ++i)
         {
             vector<CharSet> mapping(nstates, CharSet::emptySet());
-            foreach(const auto& j, rules[i])
+            for(const auto& j : rules[i])
                 mapping[j.second].unite(j.first);
             rules[i].clear();
             for(size_t j = 0; j != nstates; ++j)
@@ -407,7 +403,7 @@ public:
     }
     void dotOutput(QTextStream& out, const QString& name)
     {
-      out << "digraph " << name << "{" << endl;
+      out << "digraph " << name << "{" << Qt::endl;
       for(size_t i = 0; i != nstates; ++i)
       {
         out << "s" << i << " [ label = \"" << i << "\"";
@@ -417,16 +413,16 @@ public:
           out << ", shape=oval";
         if(i >= accept)
           out << ", penwidth=4";
-        out << " ];" << endl;
+        out << " ];" << Qt::endl;
       }
       for(size_t i = 0; i != nstates; ++i)
       {
         for(auto j = rules[i].begin(); j != rules[i].end(); ++j)
         {
-          out << "s" << i << " -> " << "s" << j->second << " [ label = \"" << j->first << "\" ];" << endl;
+          out << "s" << i << " -> " << "s" << j->second << " [ label = \"" << j->first << "\" ];" << Qt::endl;
         }
       }
-      out << "}" << endl;
+      out << "}" << Qt::endl;
     }
     /**
      * Accepts no words.
@@ -572,7 +568,7 @@ public:
         {
             if(s[i])
             {
-                foreach(const auto& r, rules[i])
+                for(const auto& r : rules[i])
                 {
                     UsedBitArray nxt(nstates);
                     nxt[r.second] = true;
@@ -647,7 +643,7 @@ public:
             states.insert(x);
             rules[x];
             vector<pair<CharSet, UsedBitArray > > nxt = follow(x);
-            foreach(const auto& nx, nxt)
+            for(const auto& nx : nxt)
             {
                 if(!nx.first.epsilon())
                 {
@@ -691,7 +687,7 @@ public:
         for(auto i = rules.begin(); i != rules.end(); ++i)
         {
             size_t key = st[i->first];
-            foreach(const auto& nx, i->second)
+            for(const auto& nx : i->second)
                 _.rules[key].push_back(make_pair(nx.first, st[nx.second]));
         }
         return _;
